@@ -435,46 +435,26 @@ class Client(Callbacks, SocketHandler):
     
     
     def get_message(self,email):
-    	shown=0
-    	while shown==0:
-    	       try:
-    	       	sleep(3)
-    	       	f=email
-    	       	mail = secmail.SecMail()
-    	       	inbox = mail.get_messages(f)
-    	       	print('done')
-    	       	for Id in inbox.id:
-    	       		msg = mail.read_message(email=f, id=Id).htmlBody
-    	       		bs = BeautifulSoup(msg, 'html.parser')
-    	       		images = bs.find_all('a')[0]
-    	       		url = (images['href']+'\n')
-    	       		if url is not None:
-    	       		  print('Vrification Url\n')
-    	       		  print(url)
-    	       		  #webbrowser.open(url)
-    	       		  shown=1
-    	       except:
-    	       	shown=0
-    	       	pass
-    	       	return shown
+      url="0"
+      try:
+        sleep(3)
+        f=email
+        mail = secmail.SecMail()
+        inbox = mail.get_messages(f)
+        print('done')
+        for Id in inbox.id:
+          msg = mail.read_message(email=f, id=Id).htmlBody
+          bs = BeautifulSoup(msg, 'html.parser')
+          images = bs.find_all('a')[0]
+          url = (images['href']+'\n')
+          if url is not None:
+            print('Vrification Url\n')
+            print(url)
+      except:
+        pass
+      return url
 
-    def verify_code(self,email):
-        #while True:
-        imgs=self.get_message(email)
-        verifycode=input("Code : ")
-        return verifycode
 
-    def register_new(self, nickname, password,deviceId):
-    	try:
-    		email=self.gen_email()
-    		print(email)
-    		self.request_verify_code(email = email)
-    		print('Verification Code Sent')
-    		vcode=self.verify_code(email)
-    		self.register(email = email,password = password,nickname = nickname, verificationCode = vcode,deviceId=deviceId)
-    		return email
-    	except Exception as a:
-    		return a
     	
 
     # Provided by "𝑰 𝑵 𝑻 𝑬 𝑹 𝑳 𝑼 𝑫 𝑬#4082"
